#include "stdafx.h"
#include "GameBall.h"


GameBall::GameBall(unsigned int radius)
{
	m_graphic.setRadius(radius);
	m_graphic.setOrigin(BALL_RADIUS, BALL_RADIUS);
	m_graphic.setFillColor(BALL_COLOR);
	m_graphic.setPosition(SCREEN_WIDTH / 2, SCREEN_HEIGHT / 2);
	m_state = 0;
	m_velocity.x = SPEED / 2;
	m_velocity.y = SPEED / 2;
}
void GameBall::setPosition(sf::Vector2f position)
{
	m_graphic.setPosition(position);
}
void GameBall::resetPosition()
{
	sf::Vector2f newPosition;
	newPosition.x = SCREEN_WIDTH / 2 + (rand() % 30 - 15);
	newPosition.y = SCREEN_HEIGHT / 2 + (rand() % 30 - 15);
	m_graphic.setPosition(newPosition);
	this->setState(0);
}
sf::Vector2f GameBall::getPosition()
{
	return m_graphic.getPosition();
}
sf::Vector2f GameBall::getPositionCentered()
{
	sf::Vector2f newPosition(m_graphic.getPosition().x - (SCREEN_WIDTH / 2), m_graphic.getPosition().y - (SCREEN_HEIGHT / 2));
	return newPosition;
}
sf::Vector2f GameBall::getVelocity()
{
	return m_velocity;
}
void GameBall::setVelocity(sf::Vector2f velocity)
{
	m_velocity = velocity;
}
void GameBall::updatePosition()
{
	m_graphic.move(m_velocity.x, m_velocity.y);
}
void GameBall::setState(int state)
{
	m_state = state;
	switch (state) {
	default:
	case 0:
		m_graphic.setFillColor(BALL_COLOR);
		break;
	case 1:
		m_graphic.setFillColor(PAD1_COLOR);
		break;
	case 2:
		m_graphic.setFillColor(PAD2_COLOR);
		break;
	}
}
int GameBall::getState()
{
	return m_state;
}
void GameBall::draw(sf::RenderWindow& win)
{
	win.draw(m_graphic);
}
bool GameBall::checkCollisionRectangle(sf::Shape& collider)
{
	return m_graphic.getGlobalBounds().intersects(collider.getGlobalBounds());
}
bool GameBall::checkCollisionPaddle(float rad_in, float rad_out)
{
	float t_Angle = m_Angle();
	if (rad_out > 2 * PI && t_Angle < PI) t_Angle += 2 * PI;
	return (rad_in <= t_Angle && rad_out >= t_Angle);

}
float GameBall::computeAngle()
{
	return m_Angle();
}

float GameBall::m_Angle()
{
	float x = this->getPositionCentered().x;
	float y = this->getPositionCentered().y;
	float angle = atan2f(y, x);
	if (angle < 0) angle += 2 * PI;

	return angle;
}
	
